# Table of Contents

- [circle-map-report](<./circle-map-report.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Circle Map Report](<./Circle-Map-Report.md>)
  - [HOW is it useful?](<./Circle-Map-Report/HOW-is-it-useful.md>)
  - [Using the Circle Map Report](<./Circle-Map-Report/Using-the-Circle-Map-Report.md>)
  - [Applying Filter](<./Circle-Map-Report/Applying-Filter.md>)
  - [Editing in the Report](<./Circle-Map-Report/Editing-in-the-Report.md>)
